@@ -109,7 +109,7 @@ if setting_config_type == "apollo":
     # 第一个测试用例文件
 
     robot = apollo_config_dict["robot"]
-    # 机器人：feishu、dingtalk或者为空
+    # 机器人：feishu、dingtalk、wechat或者为空
     # 不可混用，只能选取一种
 
     feishu_webhook = apollo_config_dict["feishu_webhook"]
@@ -128,6 +128,9 @@ if setting_config_type == "apollo":
     dingtalk_secret = apollo_config_dict["dingtalk_secret"]
     # 钉钉机器人密钥
 
+    wechat_webhook = apollo_config_dict["wechat_webhook"]
+    # 企业微信机器人webhook
+
     influxdb_switch = apollo_config_dict["influxdb_switch"]
     # 是否插入到influxDB, true或者为空
     # 不可混用，只能选取一种
@@ -163,6 +166,12 @@ if setting_config_type == "apollo":
     mongo_password = apollo_config_dict["mongo_password"]
     # MongoDB数据库配置
 
+    redis_host = apollo_config_dict["redis_host"]
+    redis_port = apollo_config_dict["redis_port"]
+    redis_password = apollo_config_dict["redis_password"]
+    redis_database = apollo_config_dict["redis_database"]
+    # Redis数据库配置
+
 if setting_config_type == "local":
 
     test_scenario = "测试场景：XXX接口测试"
@@ -190,7 +199,7 @@ if setting_config_type == "local":
     # 第一个测试用例文件
 
     robot = "feishu"
-    # 机器人：feishu、dingtalk或者为空
+    # 机器人：feishu、dingtalk、wechat或者为空
     # 不可混用，只能选取一种
 
     feishu_webhook = "https://open.feishu.cn/open-apis/bot/v2/hook/XXXXXX"
@@ -209,6 +218,9 @@ if setting_config_type == "local":
     dingtalk_secret = "1234567890abcdefghij"
     # 钉钉机器人密钥
 
+    wechat_webhook = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=XXXXXX"
+    # 企业微信机器人webhook
+
     influxdb_switch = "true"
     # 是否插入到influxDB, true或者为空
     # 不可混用，只能选取一种
@@ -245,6 +257,12 @@ if setting_config_type == "local":
         mongo_password = "123456"
         # 开发环境MongoDB数据库配置
 
+        redis_host = 'redis.dev.com'
+        redis_port = 6379
+        redis_password = '123456'
+        redis_database = 0
+        # 开发环境Redis数据库配置
+
     elif environment == "test":
         service_domain = "http://www.test.com"
         # 测试环境接口域名
@@ -270,6 +288,12 @@ if setting_config_type == "local":
         mongo_password = "123456"
         # 测试环境MongoDB数据库配置
 
+        redis_host = 'redis.test.com'
+        redis_port = 6379
+        redis_password = '123456'
+        redis_database = 0
+        # 测试环境Redis数据库配置
+
     elif environment == "pre":
         service_domain = "http://www.pre.com"
         # 预生产环境接口域名
@@ -295,6 +319,12 @@ if setting_config_type == "local":
         mongo_password = "123456"
         # 预生产环境MongoDB数据库配置
 
+        redis_host = 'redis.pre.com'
+        redis_port = 6379
+        redis_password = '123456'
+        redis_database = 0
+        # 预生产环境Redis数据库配置
+
     elif environment == "formal":
         service_domain = "https://www.formal.com"
         # 生产环境接口域名
@@ -319,3 +349,9 @@ if setting_config_type == "local":
         mongo_user = None
         mongo_password = None
         # 生产环境MongoDB数据库配置
+
+        redis_host = None
+        redis_port = None
+        redis_password = None
+        redis_database = None
+        # 生产环境Redis数据库配置
